# transports
Generic communication library

[![Build Status](https://github.com/timkpaine/transports/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/timkpaine/transports/actions?query=workflow%3A%22Build+Status%22)
[![codecov](https://codecov.io/gh/timkpaine/transports/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/transports)
[![PyPI](https://img.shields.io/pypi/l/transports.svg)](https://pypi.python.org/pypi/transports)
[![PyPI](https://img.shields.io/pypi/v/transports.svg)](https://pypi.python.org/pypi/transports)
<!-- [![npm](https://img.shields.io/npm/v/transports.svg)](https://www.npmjs.com/package/transports) -->
